pub struct Product {
pub identifiers: Box<IdentifierType>,
pub attribute_sets: Option<Vec<Value>>,
pub relationships: Option<Vec<Value>>,
pub competitive_pricing: Option<Box<CompetitivePricingType>>,
pub sales_rankings: Option<Vec<SalesRankType>>,
pub offers: Option<Vec<OfferType>>,
}Expand description
Product : An item.
Fields
identifiers: Box<IdentifierType>attribute_sets: Option<Vec<Value>>A list of product attributes if they are applicable to the product that is returned.
relationships: Option<Vec<Value>>A list that contains product variation information, if applicable.
competitive_pricing: Option<Box<CompetitivePricingType>>sales_rankings: Option<Vec<SalesRankType>>A list of sales rank information for the item, by category.
offers: Option<Vec<OfferType>>A list of offers.
Implementations